pub struct SessionAuthenticationMethod {
pub aal: Option<AuthenticatorAssuranceLevel>,
pub completed_at: Option<String>,
pub method: Option<MethodEnum>,
pub organization: Option<String>,
pub provider: Option<String>,
}Expand description
SessionAuthenticationMethod : A singular authenticator used during authentication / login.
Fields
aal: Option<AuthenticatorAssuranceLevel>completed_at: Option<String>When the authentication challenge was completed.
method: Option<MethodEnum>The method used in this authenticator. password CredentialsTypePassword oidc CredentialsTypeOIDC totp CredentialsTypeTOTP lookup_secret CredentialsTypeLookup webauthn CredentialsTypeWebAuthn code CredentialsTypeCodeAuth passkey CredentialsTypePasskey profile CredentialsTypeProfile saml CredentialsTypeSAML link_recovery CredentialsTypeRecoveryLink CredentialsTypeRecoveryLink is a special credential type linked to the link strategy (recovery flow). It is not used within the credentials object itself. code_recovery CredentialsTypeRecoveryCode
organization: Option<String>The Organization id used for authentication
provider: Option<String>OIDC or SAML provider id used for authentication
Implementations
Sourceimpl SessionAuthenticationMethod
impl SessionAuthenticationMethod
Sourcepub fn new() -> SessionAuthenticationMethod
pub fn new() -> SessionAuthenticationMethod
A singular authenticator used during authentication / login.